@@ -30,7 +30,7 @@ from localstack.config import (
 from localstack.constants import APPLICATION_JSON, BIND_HOST, HEADER_LOCALSTACK_REQUEST_URL
 from localstack.utils.aws import aws_stack
 from localstack.utils.aws.aws_responses import LambdaResponse
-from localstack.utils.common import Mock, generate_ssl_cert, json_safe, path_from_url
+from localstack.utils.common import Mock, generate_ssl_cert, json_safe, path_from_url, start_thread
 from localstack.utils.server import http2_server
 
 # set up logger
@@ -226,16 +226,23 @@ def cors_error_response():
     return response
 
 
+def _is_in_allowed_origins(allowed_origins, origin):
+    for allowed_origin in allowed_origins:
+        if allowed_origin == "*" or origin == allowed_origin:
+            return True
+    return False
+
+
 def is_cors_origin_allowed(headers, allowed_origins=None):
     """Returns true if origin is allowed to perform cors requests, false otherwise"""
     allowed_origins = ALLOWED_CORS_ORIGINS if allowed_origins is None else allowed_origins
     origin = headers.get("origin")
     referer = headers.get("referer")
     if origin:
-        return origin in allowed_origins
+        return _is_in_allowed_origins(allowed_origins, origin)
     elif referer:
         referer_uri = "{uri.scheme}://{uri.netloc}".format(uri=urlparse(referer))
-        return referer_uri in allowed_origins
+        return _is_in_allowed_origins(allowed_origins, referer_uri)
     # If both headers are not set, let it through (awscli etc. do not send these headers)
     return True
 
@@ -277,7 +284,7 @@ def modify_and_forward(
         and not is_cors_origin_allowed(headers)
     ):
         LOG.info(
-            "Blocked cors request from forbidden origin %s",
+            "Blocked CORS request from forbidden origin %s",
             headers.get("origin") or headers.get("referer"),
         )
         return cors_error_response()
@@ -553,7 +560,7 @@ def install_predefined_cert_if_available():
         pass
 
 
-def serve_flask_app(app, port, host=None, cors=True):
+def serve_flask_app(app, port, host=None, cors=True, asynchronous=False):
     if cors:
         CORS(app)
     if not config.DEBUG:
@@ -575,5 +582,10 @@ def serve_flask_app(app, port, host=None, cors=True):
     except Exception:
         pass
 
-    app.run(port=int(port), threaded=True, host=host, ssl_context=ssl_context)
-    return app
+    def _run(*_):
+        app.run(port=int(port), threaded=True, host=host, ssl_context=ssl_context)
+        return app
+
+    if asynchronous:
+        return start_thread(_run)
+    return _run()
