@@ -411,7 +411,7 @@ def check_aws_credentials():
     credentials = None
     # hardcode credentials here, to allow us to determine internal API calls made via boto3
     os.environ["AWS_ACCESS_KEY_ID"] = constants.INTERNAL_AWS_ACCESS_KEY_ID
-    os.environ["AWS_SECRET_ACCESS_KEY"] = constants.INTERNAL_AWS_ACCESS_KEY_ID
+    os.environ["AWS_SECRET_ACCESS_KEY"] = constants.INTERNAL_AWS_SECRET_ACCESS_KEY
     try:
         credentials = session.get_credentials()
     except Exception:
